@@ -23,7 +23,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 package App::Muter;
-$App::Muter::VERSION = '0.002002';
+$App::Muter::VERSION = '0.003000';
 require 5.010001;
 
 use strict;
@@ -39,7 +39,7 @@ no if $experimental, warnings => 'experimental::smartmatch';
 
 ## no critic(ProhibitMultiplePackages)
 package App::Muter::Main;
-$App::Muter::Main::VERSION = '0.002002';
+$App::Muter::Main::VERSION = '0.003000';
 use App::Muter::Backend ();
 use App::Muter::Chain   ();
 use FindBin             ();
@@ -150,7 +150,7 @@ EOM
 }
 
 package App::Muter::Interface;
-$App::Muter::Interface::VERSION = '0.002002';
+$App::Muter::Interface::VERSION = '0.003000';
 sub process {
     my ($chain, $data) = @_;
 
@@ -162,7 +162,7 @@ sub process {
 }
 
 package App::Muter::Registry;
-$App::Muter::Registry::VERSION = '0.002002';
+$App::Muter::Registry::VERSION = '0.003000';
 use File::Spec;
 
 my $instance;
@@ -196,7 +196,7 @@ sub backends {
 
 sub load_backends {
     my ($self) = @_;
-    my @modules = map { /^([A-Za-z0-9]+)\.pm$/ ? ($1) : () } map {
+    my @modules = map { /\A([A-Za-z0-9]+)\.pm\z/ ? ($1) : () } map {
         my $dh;
         opendir($dh, $_) ? readdir($dh) : ()
     } map { File::Spec->catfile($_, qw/App Muter Backend/) } @INC;
@@ -206,7 +206,7 @@ sub load_backends {
 }
 
 package App::Muter::Backend::Chunked;
-$App::Muter::Backend::Chunked::VERSION = '0.002002';
+$App::Muter::Backend::Chunked::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend/;
 
 sub new {
@@ -254,7 +254,7 @@ sub _with_chunk {
 }
 
 package App::Muter::Backend::ChunkedDecode;
-$App::Muter::Backend::ChunkedDecode::VERSION = '0.002002';
+$App::Muter::Backend::ChunkedDecode::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend/;
 
 sub new {
@@ -294,7 +294,7 @@ sub decode_final {
 }
 
 package App::Muter::Backend::Base64;
-$App::Muter::Backend::Base64::VERSION = '0.002002';
+$App::Muter::Backend::Base64::VERSION = '0.003000';
 use MIME::Base64 ();
 
 our @ISA = qw/App::Muter::Backend::Chunked/;
@@ -344,7 +344,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::URL64;
-$App::Muter::Backend::URL64::VERSION = '0.002002';
+$App::Muter::Backend::URL64::VERSION = '0.003000';
 use MIME::Base64 3.11 ();
 our @ISA = qw/App::Muter::Backend::Base64/;
 
@@ -366,7 +366,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Hex;
-$App::Muter::Backend::Hex::VERSION = '0.002002';
+$App::Muter::Backend::Hex::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -407,7 +407,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base16;
-$App::Muter::Backend::Base16::VERSION = '0.002002';
+$App::Muter::Backend::Base16::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::Hex/;
 
 sub new {
@@ -426,7 +426,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base32;
-$App::Muter::Backend::Base32::VERSION = '0.002002';
+$App::Muter::Backend::Base32::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -520,7 +520,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base32Hex;
-$App::Muter::Backend::Base32Hex::VERSION = '0.002002';
+$App::Muter::Backend::Base32Hex::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::Base32/;
 
 sub new {
@@ -537,7 +537,7 @@ sub new {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::URI;
-$App::Muter::Backend::URI::VERSION = '0.002002';
+$App::Muter::Backend::URI::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -558,7 +558,6 @@ sub metadata {
         args => {
             'upper' => 'Use uppercase letters',
             'lower' => 'Use lowercase letters',
-            'form'  => 'Encode space as +',
         }
     };
 }
@@ -579,8 +578,27 @@ sub decode_chunk {
 
 App::Muter::Registry->instance->register(__PACKAGE__);
 
+package App::Muter::Backend::Form;
+$App::Muter::Backend::Form::VERSION = '0.003000';
+our @ISA = qw/App::Muter::Backend::URI/;
+
+sub encode_chunk {
+    my ($self, $data) = @_;
+    $data = $self->SUPER::encode_chunk($data);
+    $data =~ s/%20/+/g;
+    return $data;
+}
+
+sub decode_chunk {
+    my ($self, $data) = @_;
+    $data =~ tr/+/ /;
+    return $self->SUPER::decode_chunk($data);
+}
+
+App::Muter::Registry->instance->register(__PACKAGE__);
+
 package App::Muter::Backend::XML;
-$App::Muter::Backend::XML::VERSION = '0.002002';
+$App::Muter::Backend::XML::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -638,7 +656,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::QuotedPrintable;
-$App::Muter::Backend::QuotedPrintable::VERSION = '0.002002';
+$App::Muter::Backend::QuotedPrintable::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -715,7 +733,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Vis;
-$App::Muter::Backend::Vis::VERSION = '0.002002';
+$App::Muter::Backend::Vis::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -852,7 +870,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Ascii85;
-$App::Muter::Backend::Ascii85::VERSION = '0.002002';
+$App::Muter::Backend::Ascii85::VERSION = '0.003000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -949,7 +967,7 @@ sub decode_final {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Hash;
-$App::Muter::Backend::Hash::VERSION = '0.002002';
+$App::Muter::Backend::Hash::VERSION = '0.003000';
 use Digest::MD5;
 use Digest::SHA;
 
@@ -1014,7 +1032,7 @@ App::Muter - tool to convert between various formats and encodings
 
 =head1 VERSION
 
-version 0.002002
+version 0.003000
 
 =head1 DESCRIPTION
 
